class fliicoin:
    def blocks(type):
        if type.lower() == 'all':
            return ('Network Blocks (amount per block):\nFast: 10\nMedium: 5\nSlow: 3\nUltra-Slow: 1')
        elif type.lower() == 'fast':
            return ('Fast Network Block: 10')
        elif type.lower() == 'medium':
            return ('Medium Network Block: 10')
        elif type.lower() == 'slow':
            return ('Slow Network Block: 10')
        elif type.lower() == 'ultra-slow':
            return ('Ultra-slow Network Block: 10')
        else:
            return ('Invalid network type. Please use fast, medium, slow, ultra-slow, or all')

    def block(type):
        print('Please use blocks instead of block')

    def server():
        import requests
        link = ('https://www.fliicoin.com/api/server')
        f = requests.get(link)
        return (f.text)

    def mine(username, input):
        import requests
        link = ('https://www.fliicoin.com/mine?username=' + username + '&guess=' + input)
        f = requests.get(link)
        return (f.text)


from setuptools import setup, find_packages

with open('README.md') as readme_file:
    README = readme_file.read()

with open('HISTORY.md') as history_file:
    HISTORY = history_file.read()

setup_args = dict(
    name='Fliicoin',
    version='0.1.8',
    description='Useful API commands to interact with the fliicoin network.',
    long_description_content_type="text/markdown",
    long_description=README + '\n\n' + HISTORY,
    license='MIT',
    packages=find_packages(),
    author='Fliicoin',
    author_email='admin@fliicoin.com',
    keywords=['Fliicoin', 'Flii', 'Fliic', 'Fliicoin.com', 'Fliicoin api', 'Flii api'],
    url='https://github.com/Fliicoin/Fliicoin-API',
    download_url='https://pypi.org/project/Fliicoin-API/'
)

install_requires = [
]

if __name__ == '__main__':
    setup(**setup_args, install_requires=install_requires)